core-service
============

`core-service` is a package aimed to provide a simple wrapper for asynchronous service.

Features:

* simple start/stop asynchronous Service interface
* nested services
* simple service orchestration
* service-bound asyncio tasks management
* 100% test coverage

You can support project development by staring it on github.

You can also donate ETH to our address:

    0x957D0b2E4afA74A49bbEa4d7333D13c0b11af60F
